README
======

Console
-------

.. literalinclude:: ../../../qtrio/examples/readme/console.py


Qt
--

.. literalinclude:: ../../../qtrio/examples/readme/qt.py


QTrio
-----

.. literalinclude:: ../../../qtrio/examples/readme/qtrio.py
